README
==========================================================================
Author : Christopher Torng
Date   : June 7, 2019

This ASIC design kit uses FreePDK45 and the NanGate Open Cell Library.

More information is available in the README of the standard base kit
located here:

- http://www.csl.cornell.edu/~ctorng/dropbox/pkg-freepdk45-nangate.tar.gz

This repository only contains the tiny base kit necessary to push a
design through synthesis and place and route but not further (e.g.,
DRC, LVS). The standard base kit contains the technology and library
files to run through synthesis, place and route, and signoff steps.


